@@ -83,7 +83,7 @@ void NotifyCenterWidget::initUI()
     m_clearButton->setOpacity(IconButton::RELEASE, 255 * 0.0);
     m_clearButton->setRadius(Notify::CenterTitleHeight / 2);
     m_clearButton->setFixedSize(Notify::CenterTitleHeight, Notify::CenterTitleHeight);
-    m_clearButton->setFocusPolicy(Qt::StrongFocus);
+    m_clearButton->setFocusPolicy(Qt::ClickFocus);
 
     QHBoxLayout *head_Layout = new QHBoxLayout;
     head_Layout->addWidget(bell_notify, Qt::AlignLeft | Qt::AlignTop);
@@ -97,6 +97,7 @@ void NotifyCenterWidget::initUI()
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->setContentsMargins(Notify::CenterMargin, Notify::CenterMargin, 0, 0);
     mainLayout->addWidget(m_headWidget);
+    mainLayout->addSpacing(20);
     mainLayout->addWidget(m_notifyWidget);
 
     setLayout(mainLayout);
@@ -277,10 +278,19 @@ void NotifyCenterWidget::registerRegion()
     if (interface.isValid()) {
         m_regionConnect = connect(m_regionMonitor, &DRegionMonitor::buttonRelease, this, [ = ](const QPoint & p) {
             QPoint pScale(int(qreal(p.x() / m_scale)), int(qreal(p.y() / m_scale)));
-            if (!geometry().contains(pScale))
-                if (!isHidden()) {
-                    hideAni();
-                }
+            // 多屏开缩放下，qt坐标有问题，需要手动计算
+            QScreen *screen = windowHandle()->screen();
+            if (screen) {
+                const QRect screenRect = screen->geometry();
+                QRect rect = geometry();
+                rect.setX(screenRect.x() / m_scale + geometry().x() - screenRect.x());
+                if (!rect.contains(pScale))
+                    if (!isHidden()) {
+                        hideAni();
+                    }
+            } else {
+                qWarning() << "windowHandle()->screen() is null";
+            }
         });
     }
 
